@@ -241,13 +241,13 @@ define ([
                 entry,
                 i,
                 r;
-            // console.log("miniMenu is ", mm);
-            // console.log("miniMenu length is " + len);
+            console.log("miniMenu is ", mm);
+            console.log("miniMenu length is " + len);
             if (len > 0) {
                 r = 'Menu:&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
                 for (i = 0; i < len; i += 1) {
-                    // console.log("i === " + i);
-                    // console.log("Attempting to pull target " + entries[i] + " from miniMenu");
+                    console.log("i === " + i);
+                    console.log("Attempting to pull target " + entries[i] + " from miniMenu");
                     entry = target.pull(entries[i]);
                     if (lib.privCheck(entry.aclProfile)) {
                         r += i + '. ' + entry.menuText + '&nbsp;&nbsp;';
@@ -296,11 +296,19 @@ define ([
             // if any are missing, write an error
             // return true (OK) or false (NOT OK)
             for (var i = 0; i < arr.length; i += 1) {
-                if (typeof arr[i] !== "object" ||
-                    arr[i] === null ||
-                    arr[i].text === undefined)
-                {
-                    console.log("CRITICAL ERROR: target definition ->" + tgt + "<- mentions non-existent entry");
+                if (typeof arr[i] !== "object") {
+                    console.log("ERROR: target definition ->" + tgt + "<- " +
+                                "mentions non-existent entry " + i);
+                    return false;
+                }
+                if (arr[i] === null) {
+                    console.log("ERROR: target definition ->" + tgt + "<- " +
+                                " contains null entry " + i);
+                    return false;
+                }
+                if (arr[i].name === undefined) {
+                    console.log("ERROR: target definition ->" + tgt + "<- " +
+                                "is missing a \"name\" property " + i);
                     return false;
                 }
             }
@@ -499,12 +507,15 @@ define ([
                 console.log("Processing " + len + " read-write dform entries");
                 for (i = 0; i < len; i += 1) {
                     entry = dfo.entriesWrite[i];
+                    if (! entry.hasOwnProperty('size') && entry.hasOwnProperty('maxlen')) {
+                        entry.size = entry.maxlen;
+                    }
                     if (lib.privCheck(entry.aclProfileWrite)) {
                         r += lib.rightPadSpaces(entry.text.concat(':'), needed);
                         r += '<input id="' + entry.name + '" ';
                         r += 'name="entry' + i + '" ';
                         r += 'value="' + valueToDisplay(obj, entry.prop, "write") + '" ';
-                        r += 'size="' + entry.maxlen + '" ';
+                        r += 'size="' + entry.size + '" ';
                         r += 'maxlength="' + entry.maxlen + '"><br>';
                     }
                 }
